+++
title = "URL Front-matter"
tags = ["front-matter", "url"]
url = "foo/bar/zoo/url-front-matter"
draft = false
+++

The `url` front-matter is used to specify **the full path to the
content from the web root**. It makes no assumptions about the path of
the content file. It also ignores any language prefixes of the
multilingual feature.

[Reference](https://gohugo.io/content-management/front-matter/#predefined)
